0.3.4 (2012-09-11)
------------------

* Added a CSV summary admin action for registration
* Added event tracks and schedule items
* Added a schedule view for an event

0.3.3 (2012-09-04)
------------------

* Modified Talk owner information display for cases where owner has no name

0.3.2 (2012-09-04)
------------------

* Added Talk owner information to list display in Admin

0.3.1 (2012-08-31)
------------------

* Added an admin action for even choice summaries

0.3 (2012-08-21)
----------------

* Transactions
* Payment gateway integration

0.2 (2012-07-23)
----------------

* Added Talks

0.1 (2012-07-03)
----------------

* First Release
* Models for events, registration, fees and event choices
* Views for listing events and registering
* Signal for e-mailing attendees a verification
* Signal for e-mailing managers when new registrations are added

